from mayan.apps.appearance.classes import Icon

icon_shareable_links = Icon(
    driver_name='fontawesome', symbol='handshake'
)
icon_shareable_link_create = Icon(
    driver_name='fontawesome-dual', primary_symbol='handshake',
    secondary_symbol='plus'
)
icon_shareable_link_delete = Icon(
    driver_name='fontawesome', symbol='times'
)
icon_shareable_link_edit = Icon(
    driver_name='fontawesome', symbol='pencil-alt'
)
icon_shareable_link_list = icon_shareable_links
icon_shareable_link_setup = icon_shareable_links
