# Generated by Django 2.2.15 on 2020-12-20 07:59

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('documents', '0054_trasheddocument'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShareableLink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.TextField(help_text='Text describing of this link.', verbose_name='Description')),
                ('uuid', models.UUIDField(default=uuid.uuid4, help_text='Universally Unique ID. A unique identifier generated for each link.', verbose_name='UUID')),
                ('document', models.ForeignKey(help_text='The document to which to link.', on_delete=django.db.models.deletion.CASCADE, related_name='shareable_links', to='documents.Document', verbose_name='Document')),
            ],
            options={
                'verbose_name': 'Shareable link',
                'verbose_name_plural': 'Shareable links',
            },
        ),
    ]
