# Generated by Django 2.2.15 on 2020-12-20 07:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shareable_links', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shareablelink',
            name='description',
            field=models.TextField(blank=True, help_text='Text describing of this link.', verbose_name='Description'),
        ),
    ]
